package SPVM::Net::SSLeay::PEM;



1;

=head1 Name
Short Description
SPVM::Net::SSLeay::PEM - PEM

=head1 Description

The Net::SSLeay::PEM class of L<SPVM> has methods to manipulate PEM.

=head1 Usage

  use Net::SSLeay::PEM;

=head1 Class Methods

=head2 read_bio_X509

C<static method read_bio_X509 : Net::SSLeay::X509 ($bp : L<Net::SSLeay::BIO|SPVM::Net::SSLeay::BIO>);>

=head2 read_bio_X509_CRL

C<static method read_bio_X509_CRL : Net::SSLeay::X509_CRL ($bp : L<Net::SSLeay::BIO|SPVM::Net::SSLeay::BIO>);>

=head1 Copyright & License

Copyright (c) 2023 Yuki Kimoto

MIT License

